@@ -1158,9 +1158,8 @@
         const m = userAgent.match(/chrom[e|ium]\/([^ ]+)/);
         if (m && m[1]) {
             return m[1];
-        } else {
-            return "";
         }
+        return "";
     })();
     (() => {
         try {
@@ -1170,14 +1169,6 @@
             return false;
         }
     })();
-    (() => {
-        try {
-            new CSSStyleSheet();
-            return true;
-        } catch (err) {
-            return false;
-        }
-    })();
 
     function classes(...args) {
         const classes = [];
@@ -1265,13 +1256,16 @@
         });
         return result;
     }
+    function isElementHidden(element) {
+        return element.offsetParent === null;
+    }
 
     function Button(props, ...children) {
         const cls = mergeClass("button", props.class);
         const attrs = omitAttrs(["class"], props);
         return m(
             "button",
-            Object.assign({class: cls}, attrs),
+            {class: cls, ...attrs},
             m("span", {class: "button__wrapper"}, children)
         );
     }
@@ -1661,13 +1655,12 @@
     function TextBox(props) {
         const cls = mergeClass("textbox", props.class);
         const attrs = omitAttrs(["class", "type"], props);
-        return m(
-            "input",
-            Object.assign(
-                {class: cls, type: "text", spellcheck: "false"},
-                attrs
-            )
-        );
+        return m("input", {
+            class: cls,
+            type: "text",
+            spellcheck: "false",
+            ...attrs
+        });
     }
 
     function scale(x, inLow, inHigh, outLow, outHigh) {
@@ -1677,6 +1670,14 @@
         return Math.min(max, Math.max(min, x));
     }
 
+    const hsbPickerDefaults = {
+        wasPrevHidden: true,
+        hueCanvasRendered: false,
+        activeHSB: null,
+        activeChangeHandler: null,
+        hueTouchStartHandler: null,
+        sbTouchStartHandler: null
+    };
     function rgbToHSB({r, g, b}) {
         const min = Math.min(r, g, b);
         const max = Math.max(r, g, b);
@@ -1747,7 +1748,7 @@
     }
     function HSBPicker(props) {
         const context = getComponentContext();
-        const store = context.store;
+        const store = context.getStore(hsbPickerDefaults);
         store.activeChangeHandler = props.onChange;
         const prevColor = context.prev && context.prev.props.color;
         const prevActiveColor = store.activeHSB
@@ -1764,14 +1765,21 @@
             activeHSB = store.activeHSB;
         }
         function onSBCanvasRender(canvas) {
-            const hue = activeHSB.h;
-            const prevHue = prevColor && rgbToHSB(parse(prevColor)).h;
-            if (hue === prevHue) {
+            if (isElementHidden(canvas)) {
                 return;
             }
-            renderSB(hue, canvas);
+            const hue = activeHSB.h;
+            const prevHue = prevColor && rgbToHSB(parse(prevColor)).h;
+            if (store.wasPrevHidden || hue !== prevHue) {
+                renderSB(hue, canvas);
+            }
+            store.wasPrevHidden = false;
         }
-        function onHueCanvasCreate(canvas) {
+        function onHueCanvasRender(canvas) {
+            if (store.hueCanvasRendered || isElementHidden(canvas)) {
+                return;
+            }
+            store.hueCanvasRendered = true;
             renderHue(canvas);
         }
         function createHSBSwipeHandler(getEventHSB) {
@@ -1872,7 +1880,7 @@
                 },
                 m("canvas", {
                     class: "hsb-picker__hue-canvas",
-                    oncreate: onHueCanvasCreate
+                    onrender: onHueCanvasRender
                 }),
                 m("span", {
                     class: "hsb-picker__hue-cursor",
@@ -2084,9 +2092,8 @@
         const url = new URL($url);
         if (url.host) {
             return url.host;
-        } else {
-            return url.protocol;
         }
+        return url.protocol;
     }
     function isURLInList(url, list) {
         for (let i = 0; i < list.length; i++) {
@@ -2104,9 +2111,8 @@
         } else if (!isFirstIPV6 && !isSecondIPV6) {
             const regex = createUrlRegex(urlTemplate);
             return Boolean(url.match(regex));
-        } else {
-            return false;
         }
+        return false;
     }
     function createUrlRegex(urlTemplate) {
         urlTemplate = urlTemplate.trim();
